pub struct Axis {
pub name: String,
pub tag: Tag,
pub min: UserCoord,
pub default: UserCoord,
pub max: UserCoord,
pub hidden: bool,
pub converter: CoordConverter,
pub localized_names: HashMap<String, String>,
}Expand description
A variable font axis.
Fields
name: StringA human-readable name, like ‘Weight’.
tag: TagThe axis tag, like ‘wght’.
min: UserCoordThe minimum value for this axis, in UserSpace.
default: UserCoordThe default value for this axis, in UserSpace.
max: UserCoordThe max value for this axis, in UserSpace.
converter: CoordConverterlocalized_names: HashMap<String, String>Localized names for the axis, e.g. {"en": "Weight"}
Implementations
Sourceimpl Axis
impl Axis
pub fn is_point(&self) -> bool
Sourcepub fn default_converter(&self) -> CoordConverter
pub fn default_converter(&self) -> CoordConverter
Initialize a CoordConverter for the default normalization from this axis user space.
Sourcepub fn ui_label_name(&self) -> &str
pub fn ui_label_name(&self) -> &str
Display name for the axis.
Some frontends (e.g. designspace) support the notion of an axis’ UI label name distinct
from the axis name; the former is used for displaying the axis in UI and can be
localised, whereas the latter is only used for internal cross-references.
In Designspace documents, these are stored in the axes’ <labelname> elements.
FontTools uses these to build the name records associated with axis names referenced
by fvar and STAT tables, or else falls back to the axis.name.
But even when the labelnames are ommited, there’s a special group of registered
axis names that were common in old MutatorMath source files before the <labelname>
element itself got standardised, which continue to receive a special treatment in
fonttools: i.e., the lowercase, shortened name gets replaced with a title-case,
expanded one (e.g. ‘weight’ => ‘Weight’, ‘optical’ => ‘Optical Size’ etc.).
For the sake of matching fontmake (which uses fonttools), we do the same here.
For additional info see: https://github.com/googlefonts/fontc/issues/1020